Crate bevy_flair_style

Crate bevy_flair_style 

Bevy Flair Style

Bevy Flair Style is a styling system for Bevy UI. It allows you to style your UI using CSS-like syntax.

This crate contains all the necessary components, systems and plugins to style your UI.

Modules

animations
This module contains the implementation of animations in Bevy Flair. It provides support for both keyframes and transitions animations.
components
Contains all components used by the style system.
css_selector
CSS selector implementation for Bevy Flair.
placeholder
Utilities for working with placeholders in style values.

Structs

AnimationEvent
An event representing a change in an animation.
FlairDefaultStyleAnimationsPlugin
Enables animations by using Time<Real> in the PostUpdate schedule label, which is the default behaviour.
FlairStyleAnimationsPlugin
Enables bevy_flair to work on a custom time and schedule.
FlairStylePlugin
Plugin that adds the styling systems to Bevy.
MediaSelectors
Represents a collection of media selectors, typically used in media queries.
NodePseudoState
Represents the current pseudo state of an entity. By default, it supports only the basic pseudo classes like :hover, :active, and :focus.
Ruleset
A collection of style rules, including variable definitions and property settings. Represents a body of a ruleset defined in css. It includes the properties, variables, animation and transition properties.
SingleRulesetBuilder
Helper to build a single ruleset. Useful for ad-hoc rulesets outside a full stylesheet.
StyleFontFace
Represents a font face defined in a style sheet.
StyleSheet
Represents a collection of styles that can be applied to elements, storing rules for various style properties.
StyleSheetBuilder
Builder for StyleSheet. Make sure that style sheet does not have any issues.
StyleSheetRulesetBuilder
Helper to build a single ruleset. Created using StyleSheetBuilder.
StyleSheetRulesetId
ID of a ruleset in a StyleSheet.
TransitionEvent
An event representing a change (or attempted change) in a component property, triggered during a transition process.
VarTokens
A collection of VarOrToken values.

Enums

AnimationEventType
Represents the type of event that occurred during an animation change.
ColorScheme
A color scheme that represents light or dark themes.
MediaRangeSelector
Represents a selector for media query values that allows matching ranges, like min-width or max-width
MediaSelector
Describes a single media query selector, which can match various media features.
NodePseudoStateSelector
Helper class that can be used to match against a node state.
ResolveTokensError
Errors that can occur during variable resolution.
StyleBuilderProperty
Represents a property and its value inside a StyleSheetBuilder.
StyleSheetBuilderError
Possible errors that could happen while trying to build a stylesheet.
StyleSystems
System sets for the FlairStylePlugin plugin.
TransitionEventType
Represents the type of event that occurred during a property transition change.
VarOrToken
A single item that can either be a resolved token or a reference to a variable.
VarToken
Represents a token used in variable resolution, based on CSS token types.

Traits

RulesetBuilder
Trait implemented by all ruleset builders. Implemented by StyleSheetRulesetBuilder and SingleRulesetBuilder.
ToCss
Trait for things the can serialize themselves in CSS syntax.
VarResolver
Trait for resolving variable names to their associated VarTokens.

Type Aliases

DynamicParseVarTokens
A parser function for dynamically parsing a list of VarTokens.