Bevy Flair Style
Bevy Flair Style is a styling system for Bevy UI. It allows you to style your UI using CSS-like syntax.
This crate contains all the necessary components, systems and plugins to style your UI.
Modules
- animations
- This module contains the implementation of animations in Bevy Flair. It provides support for both keyframes and transitions animations.
- components
- Contains all components used by the style system.
- css_
selector - CSS selector implementation for Bevy Flair.
- placeholder
- Utilities for working with placeholders in style values.
Structs
- Animation
Event - An event representing a change in an animation.
- Flair
Default Style Animations Plugin - Enables animations by using
Time<Real>in thePostUpdateschedule label, which is the default behaviour. - Flair
Style Animations Plugin - Enables bevy_flair to work on a custom time and schedule.
- Flair
Style Plugin - Plugin that adds the styling systems to Bevy.
- Media
Selectors - Represents a collection of media selectors, typically used in media queries.
- Node
Pseudo State - Represents the current pseudo state of an entity.
By default, it supports only the basic pseudo classes like
:hover,:active, and:focus. - Ruleset
- A collection of style rules, including variable definitions and property settings. Represents a body of a ruleset defined in css. It includes the properties, variables, animation and transition properties.
- Single
Ruleset Builder - Helper to build a single ruleset. Useful for ad-hoc rulesets outside a full stylesheet.
- Style
Font Face - Represents a font face defined in a style sheet.
- Style
Sheet - Represents a collection of styles that can be applied to elements, storing rules for various style properties.
- Style
Sheet Builder - Builder for
StyleSheet. Make sure that style sheet does not have any issues. - Style
Sheet Ruleset Builder - Helper to build a single ruleset. Created using
StyleSheetBuilder. - Style
Sheet Ruleset Id - ID of a ruleset in a
StyleSheet. - Transition
Event - An event representing a change (or attempted change) in a component property, triggered during a transition process.
- VarTokens
- A collection of
VarOrTokenvalues.
Enums
- Animation
Event Type - Represents the type of event that occurred during an animation change.
- Color
Scheme - A color scheme that represents
lightordarkthemes. - Media
Range Selector - Represents a selector for media query values that allows matching
ranges, like
min-widthormax-width - Media
Selector - Describes a single media query selector, which can match various media features.
- Node
Pseudo State Selector - Helper class that can be used to match against a node state.
- Resolve
Tokens Error - Errors that can occur during variable resolution.
- Style
Builder Property - Represents a property and its value inside a
StyleSheetBuilder. - Style
Sheet Builder Error - Possible errors that could happen while trying to build a stylesheet.
- Style
Systems - System sets for the
FlairStylePluginplugin. - Transition
Event Type - Represents the type of event that occurred during a property transition change.
- VarOr
Token - A single item that can either be a resolved token or a reference to a variable.
- VarToken
- Represents a token used in variable resolution, based on CSS token types.
Traits
- Ruleset
Builder - Trait implemented by all ruleset builders.
Implemented by
StyleSheetRulesetBuilderandSingleRulesetBuilder. - ToCss
- Trait for things the can serialize themselves in CSS syntax.
- VarResolver
- Trait for resolving variable names to their associated
VarTokens.
Type Aliases
- Dynamic
Parse VarTokens - A parser function for dynamically parsing a list of
VarTokens.